@@ -281,18 +281,6 @@ class Turkish(TurkishClass):
 
         return self.common_return(**kwargs)
 
-    def copula_simple(self, **kwargs):
-        negative = kwargs.get('negative', False)
-        question = kwargs.get('question', False)
-
-        if negative:
-            self.concat(' değil')
-
-        if question:
-            self.concat(f' m{self.minor()}')
-
-        return self.common_return(**kwargs)
-
     def copula_present(self, **kwargs):
         """
             kedidir
@@ -332,7 +320,6 @@ class Turkish(TurkishClass):
                         self.soften()
                     elif person == 1 and plural:
                         self.soften()
-                    self.harden_verb()
 
             letter_y = ''
 
@@ -344,7 +331,7 @@ class Turkish(TurkishClass):
                 [1, False, f'{letter_y}{self.minor()}m'],
                 [2, False, f's{self.minor()}n'],
                 [3, False, f'{self.letter_d()}{self.minor()}r'],
-                [1, True, f'{letter_y}{self.minor()}z'],
+                [1, True, f'{letter_y}{self.minor()}k'],
                 [2, True, f's{self.minor()}n{self.minor()}z'],
                 [3, True, f'{self.letter_d()}{self.minor()}r'],
             )
@@ -366,7 +353,7 @@ class Turkish(TurkishClass):
             self.concat(' değil')
 
             if question:
-                self.concat('miy')
+                self.concat(' miy')
 
             self.if_condition(
                 person, plural,
@@ -387,6 +374,14 @@ class Turkish(TurkishClass):
 
             self.concat(f'{self.letter_d()}{self.minor()}')
 
+            self.if_condition(
+                person, plural,
+                [1, False, 'm'],
+                [2, False, 'n'],
+                [1, True, 'z'],
+                [2, True, 'niz'],
+            )
+
         return self.common_return(**kwargs)
 
     def copula_indefinite_past(self, **kwargs):
@@ -397,6 +392,8 @@ class Turkish(TurkishClass):
 
         negative = kwargs.get('negative')
         question = kwargs.get('question')
+        person = kwargs.get('person', 3)
+        plural = kwargs.get('plural', False)
 
         if negative:
             if question:
@@ -413,6 +410,13 @@ class Turkish(TurkishClass):
 
             self.concat(f'm{self.minor()}ş')
 
+        self.if_condition(
+            person, plural,
+            [1, False, 'im'],
+            [2, False, 'sin'],
+            [1, True, 'iz'],
+            [2, True, 'tiniz'],
+        )
         return self.common_return(**kwargs)
 
     def infinitive(self, **kwargs):
